==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/inputs/GetWatchlistItemPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.inputs

import com.pulumi.azurenative.securityinsights.inputs.GetWatchlistItemPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property watchlistAlias The watchlist alias
 * @property watchlistItemId The watchlist item id (GUID)
 * @property workspaceName The name of the workspace.
 */
public data class GetWatchlistItemPlainArgs(
    public val resourceGroupName: String,
    public val watchlistAlias: String,
    public val watchlistItemId: String,
    public val workspaceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.securityinsights.inputs.GetWatchlistItemPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.securityinsights.inputs.GetWatchlistItemPlainArgs =
        com.pulumi.azurenative.securityinsights.inputs.GetWatchlistItemPlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .watchlistAlias(watchlistAlias.let({ args0 -> args0 }))
            .watchlistItemId(watchlistItemId.let({ args0 -> args0 }))
            .workspaceName(workspaceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetWatchlistItemPlainArgs].
 */
@PulumiTagMarker
public class GetWatchlistItemPlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var watchlistAlias: String? = null

    private var watchlistItemId: String? = null

    private var workspaceName: String? = null

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("kfgmlommknfewchl")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The watchlist alias
     */
    @JvmName("cxsihusdchdhakpf")
    public suspend fun watchlistAlias(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.watchlistAlias = mapped
    }

    /**
     * @param value The watchlist item id (GUID)
     */
    @JvmName("aiatsshxidvyjbcd")
    public suspend fun watchlistItemId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.watchlistItemId = mapped
    }

    /**
     * @param value The name of the workspace.
     */
    @JvmName("pcagsodtgaespvtw")
    public suspend fun workspaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workspaceName = mapped
    }

    internal fun build(): GetWatchlistItemPlainArgs = GetWatchlistItemPlainArgs(
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        watchlistAlias = watchlistAlias ?: throw PulumiNullFieldException("watchlistAlias"),
        watchlistItemId = watchlistItemId ?: throw PulumiNullFieldException("watchlistItemId"),
        workspaceName = workspaceName ?: throw PulumiNullFieldException("workspaceName"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/securityinsights/kotlin/inputs/GetWatchlistItemPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.securityinsights.kotlin.inputs

import com.pulumi.azurenative.securityinsights.inputs.GetWatchlistItemPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property watchlistAlias The watchlist alias
 * @property watchlistItemId The watchlist item id (GUID)
 * @property workspaceName The name of the workspace.
 */
public data class GetWatchlistItemPlainArgs(
    public val resourceGroupName: String,
    public val watchlistAlias: String,
    public val watchlistItemId: String,
    public val workspaceName: String,
) : ConvertibleToJava<com.pulumi.azurenative.securityinsights.inputs.GetWatchlistItemPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.securityinsights.inputs.GetWatchlistItemPlainArgs =
        com.pulumi.azurenative.securityinsights.inputs.GetWatchlistItemPlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .watchlistAlias(watchlistAlias.let({ args0 -> args0 }))
            .watchlistItemId(watchlistItemId.let({ args0 -> args0 }))
            .workspaceName(workspaceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetWatchlistItemPlainArgs].
 */
@PulumiTagMarker
public class GetWatchlistItemPlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var watchlistAlias: String? = null

    private var watchlistItemId: String? = null

    private var workspaceName: String? = null

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("frehbbbrgkvsjolw")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The watchlist alias
     */
    @JvmName("rdcqpbuobhmdkayv")
    public suspend fun watchlistAlias(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.watchlistAlias = mapped
    }

    /**
     * @param value The watchlist item id (GUID)
     */
    @JvmName("odrubmwkdywgwwoy")
    public suspend fun watchlistItemId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.watchlistItemId = mapped
    }

    /**
     * @param value The name of the workspace.
     */
    @JvmName("eorglscrdqhylctr")
    public suspend fun workspaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.workspaceName = mapped
    }

    internal fun build(): GetWatchlistItemPlainArgs = GetWatchlistItemPlainArgs(
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        watchlistAlias = watchlistAlias ?: throw PulumiNullFieldException("watchlistAlias"),
        watchlistItemId = watchlistItemId ?: throw PulumiNullFieldException("watchlistItemId"),
        workspaceName = workspaceName ?: throw PulumiNullFieldException("workspaceName"),
    )
}
